/*
 * Copyright 2017 Google Inc. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.android.installreferrer.api;

import com.android.installreferrer.api.InstallReferrerClient.InstallReferrerResponse;

/**
 * Callback for setup process. This listener's {@link #onInstallReferrerSetupFinished(int)} method
 * is called when the setup process is complete.
 */
public interface InstallReferrerStateListener {
  /**
   * Called to notify that setup is complete.
   *
   * @param responseCode The response code from {@link InstallReferrerResponse} which returns the
   *     status of the setup process.
   */
  void onInstallReferrerSetupFinished(@InstallReferrerResponse int responseCode);

  /**
   * Called to notify that connection to install referrer service was lost.
   *
   * <p>Note: This does not remove install referrer service connection itself - this binding to the
   * service will remain active, and you will receive a call to {@link
   * #onInstallReferrerSetupFinished(int)} when install referrer service is next running and setup
   * is complete.
   */
  void onInstallReferrerServiceDisconnected();
}
