/*
 * Copyright 2017 Google Inc. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.android.installreferrer.api;

import android.os.Bundle;

/** Represents an install referrer details. */
public class ReferrerDetails {
  private final Bundle mOriginalBundle;

  private static final String KEY_INSTALL_REFERRER = "install_referrer";
  private static final String KEY_REFERRER_CLICK_TIMESTAMP = "referrer_click_timestamp_seconds";
  private static final String KEY_INSTALL_BEGIN_TIMESTAMP = "install_begin_timestamp_seconds";

  public ReferrerDetails(Bundle referrerBundle) {
    mOriginalBundle = referrerBundle;
  }

  /** Returns the The referrer url of the installed package. */
  public String getInstallReferrer() {
    return mOriginalBundle.getString(KEY_INSTALL_REFERRER);
  }

  /** The timestamp in seconds when referrer click happens. */
  public long getReferrerClickTimestampSeconds() {
    return mOriginalBundle.getLong(KEY_REFERRER_CLICK_TIMESTAMP);
  }

  /** The timestamp in seconds when installation begins. */
  public long getInstallBeginTimestampSeconds() {
    return mOriginalBundle.getLong(KEY_INSTALL_BEGIN_TIMESTAMP);
  }
}
